#!/bin/bash
#
# deleteNode.sh - remove a TeamCall node under Linux (SUSE or Ubuntu)
#
# Copyright (c) 2006, 2010-2011 by ilink Kommunikationssysteme GmbH.  All Rights Reserved.
#


PATH=$PATH:/usr/bin:/usr/sbin:/sbin


# Check for root permissions
perm=`id -u` 
if [ "$perm" != "0" ]; then
    echo "You must be root to start this script"
    echo "Deleting TeamCall node canceled"
    exit 1
fi


# Path of TeamCall directory e.g. /usr/local/ilink/teamcall
cd `dirname $0`
TCSPATH=`pwd | sed -e s%/bin%%g`
#echo "TCSPATH -> $TCSPATH"
cd - > /dev/null


# Default variables 
NODENAME=""


# Get Linux distribution and specifications
DIST="unknown"
if [ "`lsb_release -i | grep -i ubuntu`" ]; then
	DIST="ubuntu"
elif [ "`lsb_release -i | grep -i suse`" ]; then
	DIST="suse"
else
	echo "Distribution not supported!"
	echo "(deleteNode.sh only supports SUSE and Ubuntu.)"
	exit 0;
fi


# Get and confirm all parameters
while [ "$checkParameter" != "OK" ]
do 
	clear
	echo "Delete a TeamCall node"
	echo ""

	echo -e "Node name of the TeamCall instance [$NODENAME]:\c " 
	read NODENAME_TMP

	if [ "$NODENAME_TMP" != "" ];then
   	   NODENAME="$NODENAME_TMP"
	fi

	echo "---------------------------------------------"
	echo "          Check your settings!"
	echo ""
	echo " TeamCall node to be deleted:  $NODENAME"
	echo ""
	echo "---------------------------------------------"

	checker="0"	
	echo -e "Are the settings correct? Then type OK: \c" 
	read checker

	if [ "$checker" == "OK" ];then
   	   checkParameter="OK"
	fi
done


# Check for the node
if [ ! -d "$TCSPATH/node_$NODENAME" ];then
	echo
	echo "The node $NODENAME does not exist!"
	echo "Can't delete this node!"
	echo ""
	exit 0
fi


# Stop TeamCall process
/etc/init.d/CSTAServer_$NODENAME stop > /dev/null
echo "TeamCall node $NODENAME stopped..."


# Delete init links
if [ "$DIST" == "ubuntu" ]; then
	update-rc.d -f CSTAServer_$NODENAME remove > /dev/Null 2>&1
fi
if [ "$DIST" == "suse" ]; then
	chkconfig --del CSTAServer_$NODENAME > /dev/Null 2>&1
fi
rm -rf /etc/init.d/CSTAServer_$NODENAME
echo "Start/stop links removed..."


# Delete directory structure
rm -rf "$TCSPATH/node_$NODENAME"
echo "Directory structure deleted..." 

